Skip to contents

Use with extreme caution! You may not be able to reactivate via the API if you are working with an older reference that is missing multiple required fields.

Usage

set_lifecycle_draft(
  reference_id,
  dev = TRUE,
  interactive = TRUE,
  verbose = FALSE
)

Arguments

reference_id

Numeric reference ID. You must have the appropriate permissions to edit this reference.

dev

Logical. Defaults to TRUE because it's best to attempt to modify references on the development & testing version of DataStore first. When everything is working, change to dev = FALSE and run again to edit the real reference.

interactive

Logical. Prompt for user confirmation before uploading?

verbose

Logical. Leave this option as FALSE unless you have reported a bug and are asked to provide diagnostic info.

Value

Invisibly returns the current lifecycle information for the reference

Examples

if (FALSE) { # \dontrun{
  lifecycle_info <- set_lifecycle_draft(reference_id = 652358)
} # }