Retrieve the current lifecycle status of a reference. Only works for internal NPS users.
Source:R/get.R
get_lifecycle_info.RdRetrieve the current lifecycle status of a reference. Only works for internal NPS users.
Arguments
- reference_id
Numeric reference ID. You must have the appropriate permissions to edit this reference.
- dev
Logical. Defaults to TRUE because it's best to attempt to modify references on the development & testing version of DataStore first. When everything is working, change to
dev = FALSEand run again to edit the real reference.- verbose
Logical. Leave this option as FALSE unless you have reported a bug and are asked to provide diagnostic info.